import 'dart:async';

import 'package:flutter/services.dart';
import 'package:kettle/kettle.dart';
import 'package:http/http.dart' as http;
import 'dart:convert';

class Kettle {
  static const MethodChannel _channel =
      MethodChannel('com.kogenta.kettle/kettle');

  static Future<bool?> start(List<KettleModule> modules) => _channel
      .invokeMethod('start', {"modules": modules.map((e) => e.value).toList()});

  static Future<bool?> stop(List<KettleModule> modules) => _channel
      .invokeMethod('stop', {"modules": modules.map((e) => e.value).toList()});

  static Future<bool?> grant(List<KettleConsent> consents) =>
      _channel.invokeMethod(
          'grant', {"consents": consents.map((e) => e.value).toList()});

  static Future<bool?> revoke(List<KettleConsent> consents) =>
      _channel.invokeMethod(
          'revoke', {"consents": consents.map((e) => e.value).toList()});

  static Future<bool?> sendDemographicProfile(int birthYear, String gender) =>
      _channel.invokeMethod(
          'sendDemographicProfile', {"birthYear": birthYear, "gender": gender});

  static Future<bool?> addCustomEvent(String type, String json) =>
      _channel.invokeMethod('addCustomEvent', {"json": json, "type": type});

  static Future<bool?> setMetadata(String type, String json) =>
      _channel.invokeMethod('setMetadata', {"json": json, "type": type});

  static Future<bool?> setLogLevel(int logLevel) =>
      _channel.invokeMethod('setLogLevel', {"logLevel": logLevel});

  static Future<String?> getIdentifier() =>
      _channel.invokeMethod('getIdentifier');

  static Future<bool?> setPushToken(String pushToken) =>
      _channel.invokeMethod('setPushToken', {"pushToken": pushToken});

  static Future<bool?> setExternalId(String externalId) =>
      _channel.invokeMethod('setExternalId', {"externalId": externalId});

  static Future<bool?> isStarted() => _channel.invokeMethod('isStarted');

  static Future<String?> getPrivacyDashboardUrl() =>
      _channel.invokeMethod('getPrivacyDashboardUrl');

  static Future<String?> getSustainabilityDashboard() =>
      _channel.invokeMethod('getSustainabilityDashboard');

  static Future<String?> getApiKey() => _channel.invokeMethod('getApiKey');

  static Future<bool?> deleteCollectedData() =>
      _channel.invokeMethod('deleteCollectedData');

  static Future<List<int>?> getGrantedConsents() =>
      _channel.invokeMethod('getGrantedConsents');

  static Future<List<int>?> getEnabledModules() =>
      _channel.invokeMethod('getEnabledModules');

  static Future<String?> getActivityEvents(int fromTime, int toTime) =>
      _channel.invokeMethod(
          'getActivityEvents', {"fromTime": fromTime, "toTime": toTime});

  static Future<String?> anonymizeLocation(double latitude, double longitude) =>
      _channel.invokeMethod(
          'anonymizeLocation', {"latitude": latitude, "longitude": longitude});

  static Future<List<KettleMessage>> getMessages() async {
    var dashboardUrl = await getPrivacyDashboardUrl();
    var urlParts = dashboardUrl!.split("?key=");
    if (urlParts.length != 2) return [];
    var apiKey = await _channel.invokeMethod('getApiKey') as String;

    var key = urlParts[1];
    var url = "https://api.pinch.services/api/v1/messaging/messages";

    var res = await http.get(Uri.parse(url),
        headers: {"Authorization": "SHA256 $key", "Api-Key": apiKey});

    if (res.statusCode == 200) {
      var msgObjects = jsonDecode(res.body) as List;
      List<KettleMessage> kettleMessages =
          msgObjects.map((msgJson) => KettleMessage.fromJson(msgJson)).toList();
      return kettleMessages;
    } else {
      return List<KettleMessage>.empty();
    }
  }
}
