import 'dart:ffi';

class RequestType {
  const RequestType._(this.value);

  final int value;

  static const RequestType location = RequestType._(1);
  static const RequestType wifi = RequestType._(2);
  static const RequestType bluetooth = RequestType._(3);
  static const RequestType motion = RequestType._(4);
  static const RequestType notification = RequestType._(5);
  static const RequestType surveys = RequestType._(6);
  static const RequestType analytics = RequestType._(7);
  static const RequestType campaigns = RequestType._(8);
  static const RequestType ads = RequestType._(9);
  static const RequestType birthYear = RequestType._(10);
  static const RequestType gender = RequestType._(11);
  static const RequestType kettle = RequestType._(12);

  static const List<RequestType> values = <RequestType>[
    location,
    wifi,
    bluetooth,
    motion,
    notification,
    surveys,
    analytics,
    campaigns,
    ads,
    birthYear,
    gender,
    kettle
  ];

  static const List<int> _names = <int>[1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12];

  @override
  String toString() => 'RequestType.${_names[value]}';
}

class KettleConsent {
  const KettleConsent._(this.value);

  final int value;

  static const KettleConsent analytics = KettleConsent._(1002);
  static const KettleConsent surveys = KettleConsent._(1001);
  static const KettleConsent campaigns = KettleConsent._(1003);
  static const KettleConsent ads = KettleConsent._(1004);

  static const List<KettleConsent> values = <KettleConsent>[
    analytics,
    surveys,
    campaigns,
    ads
  ];

  static const List<int> _names = <int>[1, 2, 3, 4];

  @override
  String toString() => 'KettleConsent.${_names[value]}';
}

class KettleModule {
  const KettleModule._(this.value);

  final int value;

  static const KettleModule location = KettleModule._(1);
  static const KettleModule bluetooth = KettleModule._(2);
  static const KettleModule activity = KettleModule._(3);

  static const List<KettleModule> values = <KettleModule>[
    location,
    bluetooth,
    activity
  ];

  static const List<int> _names = <int>[1, 2, 3];

  @override
  String toString() => 'KettleConsent.${_names[value]}';
}

class KettleMessage {
  String url;
  int expiry;
  int created;
  String title;
  String body;
  String imgUrl;
  String deliveryId;
  String messageId;
  bool opened;

  KettleMessage(this.url, this.expiry, this.created, this.title, this.body,
      this.imgUrl, this.deliveryId, this.messageId, this.opened);

  factory KettleMessage.fromJson(dynamic json) {
    return KettleMessage(
        json["url"] as String,
        json["expireTime"] as int,
        json["timestamp"] as int,
        json["messageTitle"] as String,
        json["messageBody"] as String,
        json["messageImageUrl"] as String,
        json["deliveryId"] as String,
        json["messageId"] as String,
        json["opened"] as bool);
  }

  @override
  String toString() {
    return '{${this.url}, ${this.expiry}, ${this.created}, ${this.title}, ${this.body}, ${this.imgUrl}, ${this.deliveryId}, ${this.messageId}, ${this.opened}}';
  }
}
